@@ -34,12 +34,11 @@ mod tests {
         let app = autoclap!();
         assert_eq!(
             app.get_name(),
-            "autoclap 0.1.2 :: https://github.com/mihaigalos/autoclap/releases/tag/0.1.2"
+            "autoclap 0.2.1 :: https://github.com/mihaigalos/autoclap/releases/tag/0.2.1"
         );
     }
     #[test]
-    #[ignore] // Await clap :: author<S: Into<String>>(self, author: S)
-    fn test_autoclap_author_works_when_typical() {
+    fn test_autoclap_description_works_when_typical() {
         use clap::{App, Arg};
         let app = autoclap!();
         assert_eq!(
